KeyStore

Struct KeyStore 

pub struct KeyStore { /* private fields */ }
A key store holding a private key and a chain of certificates

Implementations

Source

impl KeyStore

pub fn new<I>(key: PrivateKey, certs: I) -> Result<Self>
where I: IntoIterator<Item = Certificate>,

Create new key store. The first certificate entry must be a leaf certificate.

pub fn from_pkcs12(data: &[u8], password: &str) -> Result<Self>

Load key store from the PKCS12/PFX file

pub fn to_pkcs12(&self, alias: &str, password: &str) -> Result<Vec<u8>>

Write key store to PKCS12/PFX file

pub fn from_pkcs8(data: &[u8]) -> Result<Self>

Load key store from PEM-encoded PKCS8 file which contains both private key and certificate chain

pub fn to_pkcs8(&self) -> Result<Vec<u8>>

Write key store to PEM-encoded PKCS8 file

pub fn private_key(&self) -> &PrivateKey

Return private key of this key store

pub fn certs(&self) -> &[Certificate]

Return certificate chain of this key store, leaf certificate first